@@ -1,16 +1,15 @@
 import sys
 import os
 import json
-# import mat4py
 import scipy.io as io
 from scipy.interpolate import UnivariateSpline
 import scipy.interpolate as interp
+from scipy.io import savemat
 import numpy as np
 from scipy.signal import find_peaks
 import pandas as pd
 import math
-import popUpAlgoFollow
-# from scipy.interpolate import splprep, splev, splrep
+import zebrazoom.code.popUpAlgoFollow as popUpAlgoFollow
 
 def IsMinOrMax(maxpeaks, minpeaks, val ):
   is_minOrMax = 0
@@ -24,6 +23,57 @@ def IsMinOrMax(maxpeaks, minpeaks, val ):
       is_minOrMax=1
   return is_minOrMax
 
+# def calculateAllTailAngles(curbout, tailAngleSmoothingFactor, hyperparameters):
+  # nbFramesTakenIntoAccount = len(curbout["TailAngle_Raw"])
+  # fin = curbout["BoutEnd"] - curbout["BoutStart"] + 1
+  # headx = curbout["HeadX"]
+  # heady = curbout["HeadY"]
+  # tailx = curbout["TailX_VideoReferential"]
+  # taily = curbout["TailY_VideoReferential"]
+  # heading = curbout["Heading"]
+  # tailangles_arr = np.zeros((nbFramesTakenIntoAccount,8))
+  
+  # for i in range(min(len(headx),tailangles_arr.shape[0])):
+    # if len(taily[i]) > 3 and len(tailx[i]) > 3:
+      # ang = np.arctan2(heady[i] - taily[i][-3], headx[i] - tailx[i][-3])
+      # for j in range(1, tailangles_arr.shape[1]):
+        # ang2 = np.arctan2(heady[i] - taily[i][j], headx[i] - tailx[i][j])
+        # delang = ang2 - ang
+        # if np.abs(delang) < np.pi:
+          # tailangles_arr[i,j] = delang
+        # elif delang > np.pi:
+          # tailangles_arr[i,j] = delang - 2*np.pi
+        # elif delang < -np.pi:
+          # tailangles_arr[i,j] = 2*np.pi + delang
+    # else:
+      # for j in range(tailangles_arr.shape[1]):
+        # tailangles_arr[i,j] = 0
+  # tailangles_arr = np.transpose(tailangles_arr)
+  # tailangles_arr = np.append(tailangles_arr, np.array([[-val for val in curbout["TailAngle_Raw"]]]), axis=0)
+  
+  # tailangles_arr_smoothed = np.zeros((0, nbFramesTakenIntoAccount))
+  # for angle_raw in tailangles_arr:
+    # rolling_window = hyperparameters["tailAngleMedianFilter"]
+    # if rolling_window > 0:
+      # shift = int(-rolling_window / 2)
+      # angle_median = np.array(pd.Series(angle_raw).rolling(rolling_window).median())
+      # angle_median = np.roll(angle_median, shift)
+      # for ii in range(0, rolling_window):
+        # angle_median[ii] = angle_raw[ii]
+      # for ii in range(len(angle_median)-rolling_window,len(angle_median)):
+        # angle_median[ii] = angle_raw[ii]
+    # else:
+      # angle_median = angle_raw
+    # tailToSmooth = angle_median
+    # x = np.linspace(0, 1, len(tailToSmooth))
+    # s = UnivariateSpline(x, tailToSmooth, s=tailAngleSmoothingFactor)
+    # tailSmoothed     = s(x)
+    # tailSmoothed2    = np.zeros((1, nbFramesTakenIntoAccount))
+    # tailSmoothed2[0] = tailSmoothed
+    # tailangles_arr_smoothed = np.append(tailangles_arr_smoothed, tailSmoothed2, axis=0)
+  # return [tailangles_arr, tailangles_arr_smoothed]
+
+
 def createSuperStruct(dataPerWell, wellPositions, hyperparameters):
 
   nbWells                      = hyperparameters["nbWells"]
@@ -43,9 +93,8 @@ def createSuperStruct(dataPerWell, wellPositions, hyperparameters):
     nbMouv = len(j)
     
     tab  = [[] for idAnimal in range(0, hyperparameters["nbAnimalsPerWell"])]
-    # tab2 = []
     
-    for i in range(0,nbMouv):
+    for i in range(0, nbMouv):
       item = j[i]
       
       angle_raw = item["TailAngle_Raw"]
@@ -59,68 +108,26 @@ def createSuperStruct(dataPerWell, wellPositions, hyperparameters):
           angle_median = np.roll(angle_median, shift)
           for ii in range(0, rolling_window):
             angle_median[ii] = angle_raw[ii]
-            # jj = rolling_window - 1 - ii
-            # if math.isnan(angle_median[jj]):
-              # angle_median[jj] = angle_median[jj+1]
           for ii in range(len(angle_median)-rolling_window,len(angle_median)):
             angle_median[ii] = angle_raw[ii]
-            # if math.isnan(angle_median[ii]):
-              # angle_median[ii] = angle_median[ii-1]
         else:
           angle_median = angle_raw
-          
-        # rolling_window = 3
-        # if rolling_window > 0:
-          # shift = int(-rolling_window / 2)
-          # angle_median2 = np.array(pd.Series(angle_raw).rolling(rolling_window).median())
-          # angle_median2 = np.roll(angle_median2, shift)
-          # for ii in range(0, rolling_window):
-            # jj = rolling_window - 1 - ii
-            # if math.isnan(angle_median2[jj]):
-              # angle_median2[jj] = angle_median2[jj+1]
-          # for ii in range(len(angle_median2)-rolling_window,len(angle_median2)):
-            # if math.isnan(angle_median2[ii]):
-              # angle_median2[ii] = angle_median2[ii-1]
-        # else:
-          # angle_median2 = angle_raw
       
         x = np.linspace(0, 1, len(angle_median))
         
         # if True: # Original method
         s = UnivariateSpline(x, angle_median, s=tailAngleSmoothingFactor)
         TailAngle_smoothed = s(x) 
-        # else:
-          # tck = splrep(x, angle_median, s=0.01)
-          # TailAngle_smoothed = splev(x, tck)
-        
-        # angle_median2 = np.zeros((len(angle_median),1))
-        # angle_median2[:,0] = angle_median
-        # print(angle_median2)
-
-        # angle_median2 = np.zeros((1, len(angle_median)))
-        # angle_median2[0,:] = angle_median
-        # print(angle_median2)
-        
-        # angle_median2 = np.array(angle_median)
-        # print(angle_median2)
-        
-        # tck, u = interp.splprep(angle_median2, s=0)
-        # u = np.linspace(0, 1, len(angle_median2))
-        # TailAngle_smoothed = np.column_stack(interp.splev(u, tck))
         
         item['TailAngle_smoothed'] = TailAngle_smoothed.tolist()
       else:
         TailAngle_smoothed = np.array(angle_raw)
         item['TailAngle_smoothed'] = angle_raw
       
-      # maxDiffPeakToPeak = 0
-      # for k in range(0, len(TailAngle_smoothed)):
-        # wind = hyperparameters["windowForLocalBendMinMaxFind"]
-        # if (k - wind >= 0) and (k + wind < len(TailAngle_smoothed)):
-          # maxAngle = max([TailAngle_smoothed[k + l] for l in range(-wind, wind+1)])
-          # minAngle = min([TailAngle_smoothed[k + l] for l in range(-wind, wind+1)])
-          # if (maxAngle - minAngle > maxDiffPeakToPeak):
-            # maxDiffPeakToPeak = maxAngle - minAngle
+      # if hyperparameters["calculateAllTailAngles"]:
+        # [tailangles_arr, tailangles_arr_smoothed] = calculateAllTailAngles(item, tailAngleSmoothingFactor, hyperparameters)
+        # item["allTailAngles"]         = tailangles_arr.tolist()
+        # item["allTailAnglesSmoothed"] = tailangles_arr_smoothed.tolist()
       
       if hyperparameters['extractAdvanceZebraParameters']:
       
@@ -132,8 +139,7 @@ def createSuperStruct(dataPerWell, wellPositions, hyperparameters):
         minProminenceForBendsDetect = hyperparameters["minProminenceForBendsDetect"]
         if minProminenceForBendsDetect == -1:
           minProminenceForBendsDetect = maxDiffPeakToPeak / 10
-          
-        # TailAngle_smoothed = angle_median2
+        
         maxpeaks, properties = find_peaks(TailAngle_smoothed, prominence=minProminenceForBendsDetect, width=hyperparameters["windowForLocalBendMinMaxFind"])
         minpeaks, properties = find_peaks(-TailAngle_smoothed, prominence=minProminenceForBendsDetect, width=hyperparameters["windowForLocalBendMinMaxFind"])
         
@@ -144,7 +150,6 @@ def createSuperStruct(dataPerWell, wellPositions, hyperparameters):
           
           Bend_Timing = []
           lastTailValue = 100000
-          # Bend_TimingAbsolute(1)=floor((debut+fin)/2)
 
           for i in range(item['BoutStart'],item['BoutEnd']+1):
           
@@ -203,8 +208,6 @@ def createSuperStruct(dataPerWell, wellPositions, hyperparameters):
           
           Bend_Amplitude = [TailAngle_smoothed[val-1] for val in Bend_Timing]
           item['Bend_Amplitude'] = Bend_Amplitude
-            
-          #####
           
           tab[item["AnimalNumber"]].append(item)
           
@@ -214,36 +217,35 @@ def createSuperStruct(dataPerWell, wellPositions, hyperparameters):
           item['Bend_Amplitude'] = []
           item['TailAngle_raw'] = []
           item['TailAngle_smoothed'] = []
-          tab[item["AnimalNumber"]].append(item)          
+          tab[item["AnimalNumber"]].append(item)
         
       else:
         item['TailAngle_raw'] = []
         item['TailAngle_smoothed'] = []
         tab[item["AnimalNumber"]].append(item)
     
-    # tab2.append(tab)
     wellPoissMouv.append(tab)
   
   videoDataResults['wellPoissMouv'] = wellPoissMouv
   videoDataResults['wellPositions'] = wellPositions
   videoDataResults['firstFrame']    = hyperparameters["firstFrame"]
   
-  path = hyperparameters["outputFolder"] + hyperparameters["videoName"] + '/results_' + hyperparameters["videoName"]
+  path = os.path.join(os.path.join(hyperparameters["outputFolder"], hyperparameters["videoName"]), 'results_' + hyperparameters["videoName"] + '.txt')
   
-  # io.savemat(path + '.mat', videoDataResults)
+  print("createSuperStruct:", path)
   
-  with open(path + '.txt', 'w') as outfile:
+  with open(path, 'w') as outfile:
     json.dump(videoDataResults, outfile)
     
+  if hyperparameters["saveSuperStructToMatlab"]:
+    matlabPath = os.path.join(os.path.join(hyperparameters["outputFolder"], hyperparameters["videoName"]), 'results_' + hyperparameters["videoName"] + '.mat')
+    videoDataResults2 = {}
+    videoDataResults2['videoDataResults'] = videoDataResults
+    savemat(matlabPath, videoDataResults2)
+    
   if (hyperparameters["freqAlgoPosFollow"] != 0):
     print("Super Structure created")
   if hyperparameters["popUpAlgoFollow"]:
     popUpAlgoFollow.prepend("Super Structure created")
 
   return videoDataResults
-  
-
-# saving results in matlab file
-# io.savemat('results.mat', videoDataResults2)
-
-
