@@ -44,7 +44,7 @@ def getConfig(config, variableName, videoPath):
         if variableName == "firstFrame":
           return 1
         elif variableName == "lastFrame":
-          lastFrame = int(cap.get(cv2.CAP_PROP_FRAME_COUNT)) - 2
+          lastFrame = int(cap.get(cv2.CAP_PROP_FRAME_COUNT))
           return lastFrame
         elif variableName == "videoWidth":
           frame_width  = int(cap.get(3))
@@ -346,6 +346,10 @@ def getHyperparameters(configFile, videoName, videoPath, argv):
   
   hyperparameters["backgroundExtractionForceUseAllVideoFrames"] = getConfig(config, "backgroundExtractionForceUseAllVideoFrames", videoPath)
   
+  hyperparameters["readjustCenterOfMassIfNotInsideContour"] = getConfig(config, "readjustCenterOfMassIfNotInsideContour", videoPath)
+  
+  hyperparameters["onlyDoTheTrackingForThisNumberOfFrames"] = getConfig(config, "onlyDoTheTrackingForThisNumberOfFrames", videoPath)
+  
   if len(argv) > 5 and not(argv[0] == "getTailExtremityFirstFrame"):
     i = 5
     while i < len(argv):
